;; Generated package description from test-simple.el  -*- no-byte-compile: t -*-
(define-package "test-simple" "1.3.2.0.20260118.164127" "Simple Unit Test Framework for Emacs Lisp" '((emacs "24.4") (compat "30.1.0.1")) :commit "502b0d299724256b1bbb08dcff227ac528f1a01a" :authors '(("Rocky Bernstein" . "rocky@gnu.org")) :maintainer '("Rocky Bernstein" . "rocky@gnu.org") :keywords '("lisp") :url "https://github.com/rocky/emacs-test-simple")
